PWDMeter
========

A password strength measuring library.


Install
-------
::

    pip install pwdmeter
    

Features
--------

* casemix checker
* charmix checker
* length checker
* non-dictionary checker
* non-ascii checker
* repetitions checker
* i18n support
